@@ -7,16 +7,18 @@ import os
 import pydeface.utils as pdu
 import time
 
-from ttictoc import TicToc
+from ttictoc import Timer
 from fmri_anonymizer.directory_replicator import replicate_structure
 from fmri_anonymizer.file_searcher import walk_through
 from fmri_anonymizer.deidentifier import de_identifier
 
+from nipype.interfaces.dcm2nii import Dcm2niix
+
 __author__ = "Hugo Angulo"
 __copyright__ = "Copyright 2020, CaosLab"
 __credits__ = ["Hugo Angulo"]
 __license__ = "MIT"
-__version__ = "0.0.2"
+__version__ = "0.1.0"
 __maintainer__ = "Hugo Angulo"
 __email__ = "hugoanda@andrew.cmu.edu"
 __status__ = "Production"
@@ -25,7 +27,7 @@ __status__ = "Production"
 def str2bool(arg):
     if isinstance(arg, bool):
         return arg
-    if arg.lower() in ('YES', 'Yes', 'yes', 'Y', 'y', 'TRUE', 'True', 'true', 'T', 't', '1', ''):
+    if arg.lower() in ('YES', 'Yes', 'yes', 'Y', 'y', 'TRUE', 'True', 'true', 'T', 't', '1', ' '):
         return True
     elif arg.lower in ('NO', 'No', 'no', 'N', 'n', 'FALSE', 'False', 'false', 'F', 'f', '0'):
         return False
@@ -57,7 +59,7 @@ def get_parser():
     parser.add_argument('-i', '--input', type=str, help='Path where all the DICOM files can be found.',
                         required=True)
     parser.add_argument('-d', '--dicom', type=str2bool, nargs='?', help='Flag to enable DICOM files discovery.',
-                        const=True, default=True, required=True)
+                        const=True, default=False, required=True)
     parser.add_argument('-n', '--nifti', type=str2bool, nargs='?', help='Flag to enable NIFTI files discovery',
                         const=True, default=False, required=False)
     parser.add_argument('-a', '--anonymize', type=str2bool, nargs='?', help='Flag to enable PHI metadata scrubbing.',
@@ -86,8 +88,8 @@ def main(argv=None):
 
     dicom_formats = ['.dcm', '.ima', '.IMA']
     nifti_formats = ['nii', 'nii.gz']
-    t = TicToc()
-    t.tic()
+    t = Timer()
+    t.start()
     parser = get_parser()
     args = parser.parse_args(argv)
     input_path = args.input
@@ -147,9 +149,17 @@ def main(argv=None):
         # TODO: Transform all the DICOM cleaned into nifti files.
         nii_de_identified = dict()
         nii_defaced = dict()
+        converter = Dcm2niix()
+        converter.inputs.compression = 5
+
         for k, v in dcm_folders.items():
             try:
-                dicom2nifti.convert_directory(dicom_directory=k, output_folder=k, compression=True, reorient=True)
+                # dicom2nifti.convert_directory(dicom_directory=k, output_folder=k, compression=False, reorient=True)
+                # dicom2nifti.dicom_series_to_nifti(dicom_directory=k, output_folder=k, reorient=True)
+                converter.inputs.source_dir = k
+                converter.inputs.output_dir = k
+                converter.run()
+
             except:
                 logger.error(f'An error has been detected while transforming the dcm files in: {k}')
                 traceback.print_exc()
@@ -171,11 +181,14 @@ def main(argv=None):
                     logger.error(f'An error has been detected while defacing the file: {v}')
                     traceback.print_exc()
                     pass
-        logger.info(f'Percentage files defaced: {sum(nii_defaced.values()) / len(nii_defaced):.3f}%')
+        try:
+            logger.info(f'Percentage files defaced: {sum(nii_defaced.values()) / len(nii_defaced):.3f}%')
+        except:
+            logger.error(f'An error has been found while calculating the total number of defaced items.')
+            traceback.print_stack()
         logger.info(f'The defacing process has finished!')
 
-    t.toc()
-    logger.info(f'Process finished. Time elapsed: {t.elapsed:.6f}s')
+    logger.info(f'Process finished. Time elapsed: {t.stop():.6f}s')
 
 
 if __name__ == '__main__':
